@@ -70,6 +70,7 @@ def E(expr,color = "red"):
     #D([expr[0],sy.N(expr[1].subs(DatosList))])
 
 def G(c_componente):#Guardar
+  global DatosList
   dentro = False
   for element in DatosList:
     if element[0] == c_componente[0]:
@@ -78,8 +79,8 @@ def G(c_componente):#Guardar
       #componente significaba con el valor actual que se desea guardar.
   
   if dentro == False:
-    global DatosList
-    DatosList = DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
+    
+    DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
   
   #Renderizado Gris
   if c_componente[1] == None or dentro == False:
